@@ -18,6 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include "config.h"
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
@@ -32,6 +33,7 @@
 #include <qimage.h>
 #include <qpopupmenu.h>
 #include <kwin.h>
+#include <kprocess.h>
 
 #include "crystalclient.h"
 #include "crystalbutton.h"
@@ -147,12 +149,26 @@ void setupOverlay(WND_CONFIG *cfg,int mode,QString filename)
 		case 0:	break;
 		case 1:{
 			cfg->overlay.resize(0,0);
-			QImage img=QImage((uchar*)lighting_data,1,60,32,NULL,0,QImage::LittleEndian);
+			QImage img=QImage((uchar*)lighting_overlay_data,1,60,32,NULL,0,QImage::LittleEndian);
 			img.setAlphaBuffer(true);
 			cfg->overlay.convertFromImage(img.smoothScale(256,::factory->titlesize));
 			break;
 		}
 		case 2:{
+			cfg->overlay.resize(0,0);
+			QImage img=QImage((uchar*)glass_overlay_data,20,64,32,NULL,0,QImage::LittleEndian);
+			img.setAlphaBuffer(true);
+			cfg->overlay.convertFromImage(img.smoothScale(256,::factory->titlesize));
+			break;
+		}
+		case 3:{
+			cfg->overlay.resize(0,0);
+			QImage img=QImage((uchar*)steel_overlay_data,28,64,32,NULL,0,QImage::LittleEndian);
+			img.setAlphaBuffer(true);
+			cfg->overlay.convertFromImage(img.smoothScale(256,::factory->titlesize));
+			break;
+		}
+		case 4:{
 			QImage img;
 			if (img.load(filename))
 			{
@@ -176,9 +192,10 @@ bool CrystalFactory::readConfig()
 	else if (value == "AlignHCenter") titlealign_ = Qt::AlignHCenter;
 	else if (value == "AlignRight") titlealign_ = Qt::AlignRight;
 	
+	drawcaption=(bool)config.readBoolEntry("DrawCaption",true);
 	textshadow=(bool)config.readBoolEntry("TextShadow",true);
 	captiontooltip=(bool)config.readBoolEntry("CaptionTooltip",true);
-	wheelTask=(bool)config.readBoolEntry("WheelTask",true);
+	wheelTask=(bool)config.readBoolEntry("WheelTask",false);
 	transparency=(bool)config.readBoolEntry("EnableTransparency",true);
 	trackdesktop=(bool)config.readBoolEntry("TrackDesktop",false);
 
@@ -239,9 +256,10 @@ bool CrystalFactory::readConfig()
 	hovereffect=config.readBoolEntry("HoverEffect",true);
 	animateHover=config.readBoolEntry("AnimateHover",true);
 	tintButtons=config.readBoolEntry("TintButtons",false);
+	menuImage=config.readBoolEntry("MenuImage",true);
 	repaintMode=config.readNumEntry("RepaintMode",1);
 	repaintTime=config.readNumEntry("RepaintTime",200);
-	buttontheme=config.readNumEntry("ButtonTheme",0);
+	buttontheme=config.readNumEntry("ButtonTheme",8);
 
 
 	setupOverlay(&active,config.readNumEntry("OverlayModeActive",0),config.readEntry("OverlayFileActive",""));
@@ -294,6 +312,7 @@ void CrystalFactory::CreateButtonImages()
 	{
 	default:
 	case 0:	// Crystal default
+		buttonImages[ButtonImageMenu]->SetNormal(crystal_menu_data);
 		buttonImages[ButtonImageHelp]->SetNormal(crystal_help_data);
 		buttonImages[ButtonImageMax]->SetNormal(crystal_max_data);
 		buttonImages[ButtonImageRestore]->SetNormal(crystal_restore_data);
@@ -310,6 +329,7 @@ void CrystalFactory::CreateButtonImages()
 		buttonImages[ButtonImageUnBelow]->SetNormal(crystal_unbelow_data);
 		break;
 	case 1: // Aqua buttons
+		buttonImages[ButtonImageMenu]->SetNormal(aqua_default_data,16,16);
 		buttonImages[ButtonImageHelp]->SetNormal(aqua_default_data,16,16);
 		buttonImages[ButtonImageMax]->SetNormal(aqua_default_data,16,16);
 		buttonImages[ButtonImageRestore]->SetNormal(aqua_default_data,16,16);
@@ -370,6 +390,7 @@ void CrystalFactory::CreateButtonImages()
 		buttonImages[ButtonImageUnBelow]->SetNormal(handpainted_unbelow_data);
 		break;
 	case 4: // SVG
+		buttonImages[ButtonImageMenu]->SetNormal(svg_menu_data);
 		buttonImages[ButtonImageHelp]->SetNormal(svg_help_data);
 		buttonImages[ButtonImageMax]->SetNormal(svg_max_data);
 		buttonImages[ButtonImageRestore]->SetNormal(svg_restore_data);
@@ -386,6 +407,10 @@ void CrystalFactory::CreateButtonImages()
 		buttonImages[ButtonImageUnBelow]->SetNormal(svg_below_data);
 		break;
 	case 5: // Vista
+		buttonImages[ButtonImageMenu]->SetNormal(vista_menu_data,26,15);
+		buttonImages[ButtonImageMenu]->SetHovered(vista_menu_hovered_data);
+		buttonImages[ButtonImageMenu]->SetPressed(vista_menu_pressed_data);
+
 		buttonImages[ButtonImageHelp]->SetNormal(vista_help_data,26,15);
 		buttonImages[ButtonImageHelp]->SetHovered(vista_help_hovered_data);
 		buttonImages[ButtonImageHelp]->SetPressed(vista_help_pressed_data);
@@ -417,11 +442,9 @@ void CrystalFactory::CreateButtonImages()
 		buttonImages[ButtonImageUnAbove]->SetHovered(vista_un_above_hovered_data);
 		buttonImages[ButtonImageUnAbove]->SetPressed(vista_un_above_pressed_data);
 
-
 		buttonImages[ButtonImageBelow]->SetNormal(vista_below_data,26,15);
 		buttonImages[ButtonImageBelow]->SetHovered(vista_below_hovered_data);
 		buttonImages[ButtonImageBelow]->SetPressed(vista_below_pressed_data);
-
 		buttonImages[ButtonImageUnBelow]->SetNormal(vista_un_below_data,26,15);
 		buttonImages[ButtonImageUnBelow]->SetHovered(vista_un_below_hovered_data);
 		buttonImages[ButtonImageUnBelow]->SetPressed(vista_un_below_pressed_data);
@@ -444,53 +467,57 @@ void CrystalFactory::CreateButtonImages()
 		buttonImages[ButtonImageClose]->setSpace(0,0);
 
 		break;
-	case 6: // Kubuntu
-		buttonImages[ButtonImageHelp]->SetNormal(kubuntu_help_data,28,17);
-		buttonImages[ButtonImageHelp]->SetHovered(kubuntu_help_hovered_data);
-		buttonImages[ButtonImageHelp]->SetPressed(kubuntu_help_pressed_data);
+	case 6: // Kubuntu Dapper
+		buttonImages[ButtonImageMenu]->SetNormal(dapper_menu_data,28,17);
+		buttonImages[ButtonImageMenu]->SetHovered(dapper_menu_hovered_data);
+		buttonImages[ButtonImageMenu]->SetPressed(dapper_menu_pressed_data);
 
-		buttonImages[ButtonImageMax]->SetNormal(kubuntu_max_data,28,17);
-		buttonImages[ButtonImageMax]->SetHovered(kubuntu_max_hovered_data);
-		buttonImages[ButtonImageMax]->SetPressed(kubuntu_max_pressed_data);
-		buttonImages[ButtonImageRestore]->SetNormal(kubuntu_restore_data,28,17);
-		buttonImages[ButtonImageRestore]->SetHovered(kubuntu_restore_hovered_data);
-		buttonImages[ButtonImageRestore]->SetPressed(kubuntu_restore_pressed_data);
-		buttonImages[ButtonImageMin]->SetNormal(kubuntu_min_data,28,17);
-		buttonImages[ButtonImageMin]->SetHovered(kubuntu_min_hovered_data);
-		buttonImages[ButtonImageMin]->SetPressed(kubuntu_min_pressed_data);
-		buttonImages[ButtonImageClose]->SetNormal(kubuntu_close_data,28,17);
-		buttonImages[ButtonImageClose]->SetHovered(kubuntu_close_hovered_data);
-		buttonImages[ButtonImageClose]->SetPressed(kubuntu_close_pressed_data);
+		buttonImages[ButtonImageHelp]->SetNormal(dapper_help_data,28,17);
+		buttonImages[ButtonImageHelp]->SetHovered(dapper_help_hovered_data);
+		buttonImages[ButtonImageHelp]->SetPressed(dapper_help_pressed_data);
 
-		buttonImages[ButtonImageSticky]->SetNormal(kubuntu_sticky_data,28,17);
-		buttonImages[ButtonImageSticky]->SetHovered(kubuntu_sticky_hovered_data);
-		buttonImages[ButtonImageSticky]->SetPressed(kubuntu_sticky_pressed_data);
-		buttonImages[ButtonImageUnSticky]->SetNormal(kubuntu_un_sticky_data,28,17);
-		buttonImages[ButtonImageUnSticky]->SetHovered(kubuntu_un_sticky_hovered_data);
-		buttonImages[ButtonImageUnSticky]->SetPressed(kubuntu_un_sticky_pressed_data);
+		buttonImages[ButtonImageMax]->SetNormal(dapper_max_data,28,17);
+		buttonImages[ButtonImageMax]->SetHovered(dapper_max_hovered_data);
+		buttonImages[ButtonImageMax]->SetPressed(dapper_max_pressed_data);
+		buttonImages[ButtonImageRestore]->SetNormal(dapper_restore_data,28,17);
+		buttonImages[ButtonImageRestore]->SetHovered(dapper_restore_hovered_data);
+		buttonImages[ButtonImageRestore]->SetPressed(dapper_restore_pressed_data);
+		buttonImages[ButtonImageMin]->SetNormal(dapper_min_data,28,17);
+		buttonImages[ButtonImageMin]->SetHovered(dapper_min_hovered_data);
+		buttonImages[ButtonImageMin]->SetPressed(dapper_min_pressed_data);
+		buttonImages[ButtonImageClose]->SetNormal(dapper_close_data,28,17);
+		buttonImages[ButtonImageClose]->SetHovered(dapper_close_hovered_data);
+		buttonImages[ButtonImageClose]->SetPressed(dapper_close_pressed_data);
 
-		buttonImages[ButtonImageAbove]->SetNormal(kubuntu_above_data,28,17);
-		buttonImages[ButtonImageAbove]->SetHovered(kubuntu_above_hovered_data);
-		buttonImages[ButtonImageAbove]->SetPressed(kubuntu_above_pressed_data);
-		buttonImages[ButtonImageUnAbove]->SetNormal(kubuntu_un_above_data,28,17);
-		buttonImages[ButtonImageUnAbove]->SetHovered(kubuntu_un_above_hovered_data);
-		buttonImages[ButtonImageUnAbove]->SetPressed(kubuntu_un_above_pressed_data);
+		buttonImages[ButtonImageSticky]->SetNormal(dapper_sticky_data,28,17);
+		buttonImages[ButtonImageSticky]->SetHovered(dapper_sticky_hovered_data);
+		buttonImages[ButtonImageSticky]->SetPressed(dapper_sticky_pressed_data);
+		buttonImages[ButtonImageUnSticky]->SetNormal(dapper_un_sticky_data,28,17);
+		buttonImages[ButtonImageUnSticky]->SetHovered(dapper_un_sticky_hovered_data);
+		buttonImages[ButtonImageUnSticky]->SetPressed(dapper_un_sticky_pressed_data);
+
+		buttonImages[ButtonImageAbove]->SetNormal(dapper_above_data,28,17);
+		buttonImages[ButtonImageAbove]->SetHovered(dapper_above_hovered_data);
+		buttonImages[ButtonImageAbove]->SetPressed(dapper_above_pressed_data);
+		buttonImages[ButtonImageUnAbove]->SetNormal(dapper_un_above_data,28,17);
+		buttonImages[ButtonImageUnAbove]->SetHovered(dapper_un_above_hovered_data);
+		buttonImages[ButtonImageUnAbove]->SetPressed(dapper_un_above_pressed_data);
 
 
-		buttonImages[ButtonImageBelow]->SetNormal(kubuntu_below_data,28,17);
-		buttonImages[ButtonImageBelow]->SetHovered(kubuntu_below_hovered_data);
-		buttonImages[ButtonImageBelow]->SetPressed(kubuntu_below_pressed_data);
+		buttonImages[ButtonImageBelow]->SetNormal(dapper_below_data,28,17);
+		buttonImages[ButtonImageBelow]->SetHovered(dapper_below_hovered_data);
+		buttonImages[ButtonImageBelow]->SetPressed(dapper_below_pressed_data);
 
-		buttonImages[ButtonImageUnBelow]->SetNormal(kubuntu_un_below_data,28,17);
-		buttonImages[ButtonImageUnBelow]->SetHovered(kubuntu_un_below_hovered_data);
-		buttonImages[ButtonImageUnBelow]->SetPressed(kubuntu_un_below_pressed_data);
+		buttonImages[ButtonImageUnBelow]->SetNormal(dapper_un_below_data,28,17);
+		buttonImages[ButtonImageUnBelow]->SetHovered(dapper_un_below_hovered_data);
+		buttonImages[ButtonImageUnBelow]->SetPressed(dapper_un_below_pressed_data);
 
-		buttonImages[ButtonImageShade]->SetNormal(kubuntu_shade_data,28,17);
-		buttonImages[ButtonImageShade]->SetHovered(kubuntu_shade_hovered_data);
-		buttonImages[ButtonImageShade]->SetPressed(kubuntu_shade_pressed_data);
-		buttonImages[ButtonImageUnShade]->SetNormal(kubuntu_un_shade_data,28,17);
-		buttonImages[ButtonImageUnShade]->SetHovered(kubuntu_un_shade_hovered_data);
-		buttonImages[ButtonImageUnShade]->SetPressed(kubuntu_un_shade_pressed_data);
+		buttonImages[ButtonImageShade]->SetNormal(dapper_shade_data,28,17);
+		buttonImages[ButtonImageShade]->SetHovered(dapper_shade_hovered_data);
+		buttonImages[ButtonImageShade]->SetPressed(dapper_shade_pressed_data);
+		buttonImages[ButtonImageUnShade]->SetNormal(dapper_un_shade_data,28,17);
+		buttonImages[ButtonImageUnShade]->SetHovered(dapper_un_shade_hovered_data);
+		buttonImages[ButtonImageUnShade]->SetPressed(dapper_un_shade_pressed_data);
 	
 		for (int i=0;i<ButtonImageCount;i++)
 		{
@@ -504,6 +531,10 @@ void CrystalFactory::CreateButtonImages()
 		break;
 
 	case 7: // Kubuntu-Edgy
+		buttonImages[ButtonImageMenu]->SetNormal(edgy_menu_data,28,17);
+		buttonImages[ButtonImageMenu]->SetHovered(edgy_menu_hovered_data);
+		buttonImages[ButtonImageMenu]->SetPressed(edgy_menu_pressed_data);
+
 		buttonImages[ButtonImageHelp]->SetNormal(edgy_help_data,28,17);
 		buttonImages[ButtonImageHelp]->SetHovered(edgy_help_hovered_data);
 		buttonImages[ButtonImageHelp]->SetPressed(edgy_help_pressed_data);
@@ -562,10 +593,73 @@ void CrystalFactory::CreateButtonImages()
 		buttonImages[ButtonImageClose]->setSpace(0,0);
 
 		break;
+	case 8: // Kubuntu-Feisty
+		buttonImages[ButtonImageMenu]->SetNormal(feisty_menu_data,21,17);
+		buttonImages[ButtonImageMenu]->SetHovered(feisty_menu_hovered_data);
+		buttonImages[ButtonImageMenu]->SetPressed(feisty_menu_pressed_data);
 
+		buttonImages[ButtonImageHelp]->SetNormal(feisty_help_data,28,17);
+		buttonImages[ButtonImageHelp]->SetHovered(feisty_help_hovered_data);
+		buttonImages[ButtonImageHelp]->SetPressed(feisty_help_pressed_data);
+
+		buttonImages[ButtonImageMax]->SetNormal(feisty_max_data,28,17);
+		buttonImages[ButtonImageMax]->SetHovered(feisty_max_hovered_data);
+		buttonImages[ButtonImageMax]->SetPressed(feisty_max_pressed_data);
+		buttonImages[ButtonImageRestore]->SetNormal(feisty_restore_data,28,17);
+		buttonImages[ButtonImageRestore]->SetHovered(feisty_restore_hovered_data);
+		buttonImages[ButtonImageRestore]->SetPressed(feisty_restore_pressed_data);
+		buttonImages[ButtonImageMin]->SetNormal(feisty_min_data,28,17);
+		buttonImages[ButtonImageMin]->SetHovered(feisty_min_hovered_data);
+		buttonImages[ButtonImageMin]->SetPressed(feisty_min_pressed_data);
+		buttonImages[ButtonImageClose]->SetNormal(feisty_close_data,28,17);
+		buttonImages[ButtonImageClose]->SetHovered(feisty_close_hovered_data);
+		buttonImages[ButtonImageClose]->SetPressed(feisty_close_pressed_data);
+
+		buttonImages[ButtonImageSticky]->SetNormal(feisty_sticky_data,28,17);
+		buttonImages[ButtonImageSticky]->SetHovered(feisty_sticky_hovered_data);
+		buttonImages[ButtonImageSticky]->SetPressed(feisty_sticky_pressed_data);
+		buttonImages[ButtonImageUnSticky]->SetNormal(feisty_un_sticky_data,28,17);
+		buttonImages[ButtonImageUnSticky]->SetHovered(feisty_un_sticky_hovered_data);
+		buttonImages[ButtonImageUnSticky]->SetPressed(feisty_un_sticky_pressed_data);
+
+		buttonImages[ButtonImageAbove]->SetNormal(feisty_above_data,28,17);
+		buttonImages[ButtonImageAbove]->SetHovered(feisty_above_hovered_data);
+		buttonImages[ButtonImageAbove]->SetPressed(feisty_above_pressed_data);
+		buttonImages[ButtonImageUnAbove]->SetNormal(feisty_un_above_data,28,17);
+		buttonImages[ButtonImageUnAbove]->SetHovered(feisty_un_above_hovered_data);
+		buttonImages[ButtonImageUnAbove]->SetPressed(feisty_un_above_pressed_data);
+
+
+		buttonImages[ButtonImageBelow]->SetNormal(feisty_below_data,28,17);
+		buttonImages[ButtonImageBelow]->SetHovered(feisty_below_hovered_data);
+		buttonImages[ButtonImageBelow]->SetPressed(feisty_below_pressed_data);
+
+		buttonImages[ButtonImageUnBelow]->SetNormal(feisty_un_below_data,28,17);
+		buttonImages[ButtonImageUnBelow]->SetHovered(feisty_un_below_hovered_data);
+		buttonImages[ButtonImageUnBelow]->SetPressed(feisty_un_below_pressed_data);
+
+		buttonImages[ButtonImageShade]->SetNormal(feisty_shade_data,28,17);
+		buttonImages[ButtonImageShade]->SetHovered(feisty_shade_hovered_data);
+		buttonImages[ButtonImageShade]->SetPressed(feisty_shade_pressed_data);
+		buttonImages[ButtonImageUnShade]->SetNormal(feisty_un_shade_data,28,17);
+		buttonImages[ButtonImageUnShade]->SetHovered(feisty_un_shade_hovered_data);
+		buttonImages[ButtonImageUnShade]->SetPressed(feisty_un_shade_pressed_data);
+	
+		for (int i=0;i<ButtonImageCount;i++)
+		{
+			buttonImages[i]->setSpace(1,0);
+			buttonImages[i]->setDrawMode(0);
+		}
+		buttonImages[ButtonImageMax]->setSpace(0,0);
+		buttonImages[ButtonImageRestore]->setSpace(0,0);
+		buttonImages[ButtonImageMin]->setSpace(0,0);
+		buttonImages[ButtonImageClose]->setSpace(0,0);
+
+		break;
 
 	}
 
+
 	for (int i=0;i<ButtonImageCount;i++)buttonImages[i]->finish();
 }
 
@@ -618,7 +712,7 @@ void CrystalClient::init()
 
 	if (isPreview()) {
 		char c[512];
-		sprintf(c,"<center><b>Crystal Preview</b><br>Built: %s</center>",__DATE__);
+		sprintf(c,"<center><b>Crystal %s Preview</b><br>Built: %s</center>",VERSION,__DATE__);
 		mainlayout->addItem(new QSpacerItem(1, 1,QSizePolicy::Expanding,QSizePolicy::Fixed), 0, 1);
 		mainlayout->addItem(new QSpacerItem(1, ::factory->borderwidth,QSizePolicy::Expanding,QSizePolicy::Expanding), 3, 1);
 		mainlayout->addWidget(new QLabel(i18n(c),widget()), 2, 1);
@@ -711,7 +805,7 @@ CrystalButton* CrystalClient::addButtons(QBoxLayout *layout, const QString& s)
 			switch (s[n]) {
 			case 'M': // Menu button
 				if (!button[ButtonMenu]) {
-					button[ButtonMenu] = current = new CrystalButton(this, "menu", i18n("Menu"), ButtonMenu, 0);
+					button[ButtonMenu] = current = new CrystalButton(this, "menu", i18n("Menu"), ButtonMenu, ::factory->buttonImages[ButtonImageMenu]);
 					connect(button[ButtonMenu], SIGNAL(pressed()), this, SLOT(menuButtonPressed()));
 				}
 				break;
@@ -820,7 +914,7 @@ void CrystalClient::activeChange()
 
 void CrystalClient::captionChange()
 {
-	widget()->repaint(titlebar_->geometry(), false);
+	if (::factory->drawcaption) widget()->repaint(titlebar_->geometry(), false);
 }
 
 void CrystalClient::desktopChange()
@@ -836,7 +930,7 @@ void CrystalClient::desktopChange()
 void CrystalClient::iconChange()
 {
 	if (button[ButtonMenu]) {
-		button[ButtonMenu]->setBitmap(0);
+		button[ButtonMenu]->setBitmap(::factory->buttonImages[ButtonImageMenu]);
 	}
 }
 
@@ -988,26 +1082,39 @@ bool CrystalClient::eventFilter(QObject *obj, QEvent *e)
 	return false;
 }
 
-void CrystalClient::ClientWindows(Window* frame,Window* wrapper,Window *client)
+void CrystalClient::ClientWindows(Window* v_frame,Window* v_wrapper,Window *v_client)
 {
-	Window root=0,parent=0,*children=NULL;
+	Window root=0,frame=0,wrapper=0,client=0,parent=0,*children=NULL;
 	uint numc;
+	if (v_frame) *v_frame=0;
+	if (v_wrapper) *v_wrapper=0;
+	if (v_client) *v_client=0;
 	// Our Deco is the child of a frame, get our parent
-	XQueryTree(qt_xdisplay(),widget()->winId(),&root,frame,&children,&numc);
+	if (XQueryTree(qt_xdisplay(),widget()->winId(),&root,&frame,&children,&numc) == 0)
+		return;
 	if (children!=NULL)XFree(children);
+	children=NULL;
 	
 	// frame has two children, us and a wrapper, get the wrapper
-	XQueryTree(qt_xdisplay(),*frame,&root,&parent,&children,&numc);	
+	if (XQueryTree(qt_xdisplay(),frame,&root,&parent,&children,&numc)==0)
+		return;
+
 	for (uint i=0;i<numc;i++)
 	{
-		if (children[i]!=widget()->winId())*wrapper=children[i];
+		if (children[i]!=widget()->winId())wrapper=children[i];
 	}
-	XFree(children);
+	if (children!=NULL)XFree(children);
+	children=NULL;
 	
 	// wrapper has only one child, which is the client. We want this!!
-	XQueryTree(qt_xdisplay(),*wrapper,&root,&parent,&children,&numc);
-	if (numc==1)*client=children[0];	
+	if (XQueryTree(qt_xdisplay(),wrapper,&root,&parent,&children,&numc)==0)
+		return;
+	if (numc==1)client=children[0];	
 	if (children!=NULL)XFree(children);
+	children=NULL;
+	if (v_client) *v_client=client;
+	if (v_wrapper) *v_wrapper=wrapper;
+	if (v_frame) *v_frame=frame;
 }
 
 void CrystalClient::mouseDoubleClickEvent(QMouseEvent *e)
@@ -1041,8 +1148,14 @@ void CrystalClient::mouseWheelEvent(QWheelEvent *e)
 			}
 			
 			n->ClientWindows(&frame,&wrapper,&client);
+			if (client == 0) { /* FALLBACK */
+#if KDE_IS_VERSION(3,5,0)
+				titlebarMouseWheelOperation(e->delta());
+#endif
+				return;
+			}
 			KWin::WindowInfo info=KWin::windowInfo(client);
-			if (n->desktop()==desktop() && !info.isMinimized())break;
+			if ((n->desktop()==desktop()) && !info.isMinimized())break;
 		}while(n!=this);
 			
 		KWin::activateWindow(client);
@@ -1089,51 +1202,61 @@ void CrystalClient::paintEvent(QPaintEvent*)
 		{
 			pufferPainter.drawTiledPixmap(0,0,widget()->width(),bt,wndcfg->overlay);
 		}
-	
-		// draw title text
-		pufferPainter.setFont(options()->font(isActive(), false));
-	
-		QColor color=options()->color(KDecoration::ColorFont, isActive());
-		r=titlebar_->geometry();
-		r.moveBy(0,-1);
-		int logowidth=::factory->logo.width()+::factory->logoDistance;
-		if (::factory->logoEnabled!=1 && (isActive()||!::factory->logoActive))
+
+		if (::factory->drawcaption)
 		{
-			r.setWidth(r.width()-logowidth);
-			if (::factory->logoEnabled==0)r.moveLeft(r.left()+logowidth);
-		}
-		int textalign=CrystalFactory::titleAlign();
-		QFontMetrics metrics(options()->font(isActive(), false));
-		int textwidth=metrics.width(caption());
-		if (textwidth>r.width())
-			textalign=AlignLeft, textwidth=r.width();
+			// draw title text
+			pufferPainter.setFont(options()->font(isActive(), false));
 		
-		if (::factory->textshadow)
-		{
-			pufferPainter.translate(1,1);
-			pufferPainter.setPen(color.dark(300));
-			pufferPainter.drawText(r,textalign | AlignVCenter,caption());
-			pufferPainter.translate(-1,-1);
-		}
-	
-		pufferPainter.setPen(color);
-		pufferPainter.drawText(r,
-			textalign | AlignVCenter,
-			caption());
-		if (::factory->logoEnabled!=1 && (isActive()||!::factory->logoActive))
-		{
-			int x=0;
-			if (::factory->logoEnabled==0 && textalign==AlignLeft)x=r.left()-logowidth;
-			if (::factory->logoEnabled==2 && textalign==AlignLeft)x=r.left()+textwidth+::factory->logoDistance;
+			QColor color=options()->color(KDecoration::ColorFont, isActive());
+			r=titlebar_->geometry();
+			r.moveBy(0,-1);
+			int logowidth=::factory->logo.width()+::factory->logoDistance;
+			if (::factory->logoEnabled!=1 && (isActive()||!::factory->logoActive))
+			{
+				r.setWidth(r.width()-logowidth);
+				if (::factory->logoEnabled==0)r.moveLeft(r.left()+logowidth);
+			}
+			QFontMetrics metrics(options()->font(isActive(), false));
+			int textwidth=metrics.width(caption());
+			int textalign=CrystalFactory::titleAlign();
+			if (textwidth>r.width())
+				textalign=AlignLeft, textwidth=r.width();			
+			if (::factory->textshadow)
+			{
+				pufferPainter.translate(1,1);
+				pufferPainter.setPen(color.dark(300));
+				pufferPainter.drawText(r,textalign | AlignVCenter,caption());
+				pufferPainter.translate(-1,-1);
+			}
+		
+			pufferPainter.setPen(color);
+			pufferPainter.drawText(r,
+				textalign | AlignVCenter,
+				caption());
 
-			if (::factory->logoEnabled==0 && textalign==AlignRight)x=r.right()-textwidth-logowidth;
-			if (::factory->logoEnabled==2 && textalign==AlignRight)x=r.right()+::factory->logoDistance;
+			if (::factory->logoEnabled!=1 && (isActive()||!::factory->logoActive))
+			{
+				int x=0;
+				if (::factory->logoEnabled==0 && textalign==AlignLeft)x=r.left()-logowidth;
+				if (::factory->logoEnabled==2 && textalign==AlignLeft)x=r.left()+textwidth+::factory->logoDistance;
 
-			if (::factory->logoEnabled==0 && textalign==AlignHCenter)x=(r.right()+r.left()-textwidth)/2-logowidth;
-			if (::factory->logoEnabled==2 && textalign==AlignHCenter)x=(r.right()+r.left()+textwidth)/2+::factory->logoDistance;
+				if (::factory->logoEnabled==0 && textalign==AlignRight)x=r.right()-textwidth-logowidth;
+				if (::factory->logoEnabled==2 && textalign==AlignRight)x=r.right()+::factory->logoDistance;
 
+				if (::factory->logoEnabled==0 && textalign==AlignHCenter)x=(r.right()+r.left()-textwidth)/2-logowidth;
+				if (::factory->logoEnabled==2 && textalign==AlignHCenter)x=(r.right()+r.left()+textwidth)/2+::factory->logoDistance;
+				pufferPainter.drawPixmap(x,(::factory->titlesize-::factory->logo.height())/2,::factory->logo);
+			}
+		}else if (::factory->logoEnabled!=1 && (isActive()||!::factory->logoActive)) {
+			int x=0;	
+			r=titlebar_->geometry();
+			if (::factory->logoEnabled==0) x=r.left();
+			if (::factory->logoEnabled==2) x=r.right()-::factory->logo.width();
 			pufferPainter.drawPixmap(x,(::factory->titlesize-::factory->logo.height())/2,::factory->logo);
+
 		}
+
 		pufferPainter.end();
 		painter.drawPixmap(0,0,pufferPixmap);
 
@@ -1284,10 +1407,10 @@ void CrystalClient::resizeEvent(QResizeEvent *e)
 			if (wnd->mode!=0 || wnd->amount<100)
 				timer.start(::factory->repaintTime,true);	
 		}
-		if (e->size()!=e->oldSize())
-		{
-			updateMask();
-		}
+	}
+	if (e->size()!=e->oldSize())
+	{
+		updateMask();
 	}
 }
 
@@ -1348,32 +1471,6 @@ void CrystalClient::minButtonPressed()
 		switch (button[ButtonMin]->lastMousePress()) {
 		case MidButton:{
 			performWindowOperation(LowerOp);
-/*			Window client,frame,wrapper;
-			ClientWindows(&frame,&wrapper,&client);
-			#define SYSTEM_TRAY_REQUEST_DOCK    0
-			
-			char buffer[128];
-			XEvent ev;
-
-  			snprintf(buffer, sizeof(buffer), "_NET_SYSTEM_TRAY_S%d", DefaultScreen(qt_xdisplay()));
-  			Atom a = XInternAtom(qt_xdisplay(), buffer, False);
-  			Window systray = XGetSelectionOwner(qt_xdisplay(), a);
-
-  			memset(&ev, 0, sizeof(ev));
-  			ev.xclient.type = ClientMessage;
-  			ev.xclient.window = systray;
-  			ev.xclient.message_type = XInternAtom(qt_xdisplay(), "_NET_SYSTEM_TRAY_OPCODE", False);
-  			ev.xclient.format = 32;
-  			ev.xclient.data.l[0] = CurrentTime;
-  			ev.xclient.data.l[1] = SYSTEM_TRAY_REQUEST_DOCK;
-  			ev.xclient.data.l[2] = widget()->winId();
-  			ev.xclient.data.l[3] = 0;
-  			ev.xclient.data.l[4] = 0;
-
-  			XSendEvent(qt_xdisplay(), systray, False, NoEventMask, &ev);
-  			XSync(qt_xdisplay(), False);
-			
-			XUnmapWindow(qt_xdisplay(),client);*/
 			break;
 		}
 		case RightButton:
@@ -1417,6 +1514,17 @@ void CrystalClient::closeButtonPressed()
 	switch (button[ButtonClose]->lastMousePress()) {
 		case RightButton:
 		{
+			Window frame,wrapper,client;
+			char param[20];
+			ClientWindows(&frame,&wrapper,&client);
+			if (client != 0) {
+				KProcess *proc = new KProcess;
+
+				*proc << "kdocker";
+				sprintf(param,"0x%lx",client);
+				*proc << "-d" << "-w" << param;
+				proc->start(KProcess::DontCare);
+			} else { /* Sorry man */ }
 			break;
 		}
 		default:
@@ -1462,7 +1570,7 @@ void CrystalClient::menuButtonPressed()
 void CrystalClient::menuPopUp()
 {
 	QPoint p(button[ButtonMenu]->rect().bottomLeft().x(),
-                 button[ButtonMenu]->rect().bottomLeft().y());
+                 button[ButtonMenu]->rect().bottomLeft().y()+2);
 	KDecorationFactory* f = factory();
 	showWindowMenu(button[ButtonMenu]->mapToGlobal(p));
 	if (!f->exists(this)) return; // decoration was destroyed
